==> Sonic-Pi-for-RPi-Wheezy-v2.8.0.tgz: sonic-pi-v2.8.0/CONTRIBUTORS.md <==
# Contributors

## Support and Advice

Thanks to the following people for their generous support (both
technical and otherwise) with time, advice, and wisdom:

* [Carrie Anne Philbin](https://twitter.com/missphilbin)
* [Robert Mullins](http://www.cl.cam.ac.uk/~rdm34/)
* [Alex Bradbury](https://twitter.com/asbradbury)
* [Alan Blackwell](http://www.cl.cam.ac.uk/~afb21/)
* [Rachel Drury](https://twitter.com/Rachel_Drury)
* [Juneau Projects](http://www.juneauprojects.co.uk)
* Stephan Lachowsky

## Organisations

The following organisations have kindly contributed to Sonic Pi:

* [The Raspberry Pi Foundation](http://www.raspberrypi.org)
* [The Broadcom Foundation](http://www.broadcomfoundation.org)
* [The University of Cambridge Computer Laboratory](http://www.cl.cam.ac.uk)
* [Nesta](http://www.nesta.org.uk)

## Developer Contributions

In addition to the Sonic Pi Core Team, I'd like to give my thanks to
the following developers who have donated their time and effort to help
grow and improve the Sonic Pi code base:

* [Hanno Zulla](https://github.com/hzulla)
* [Łukasz Siwiński](https://github.com/hopbit)
* [Ethan Crawford](https://github.com/ethancrawford)
* [Martin Keegan](https://github.com/mk270)
* [Nicolas Dermine](https://github.com/nicoder)
* [Wolfgang Werner](https://github.com/wwerner)
* [Robin Newman](https://github.com/rbnpi)
* [Clare Macrae](https://github.com/claremacrae)
* [G. Martin Butz](https://github.com/mbutz)
* [Hannes Fritz](https://github.com/hztirf)
* [Keiko Machiya](https://github.com/keikomachiya)
* [Marco Giordano](https://github.com/marco-giordano)
* [Martin Zeilinger](https://github.com/st01c)
* [Steve Traylen](https://github.com/traylenator)
* [Ben Nuttall](https://github.com/bennuttall)
* [Will Stephenson](https://github.com/wstephenson)
* [Chris Ford](https://github.com/ctford)
* [Kenichi Kanai](https://github.com/kn1kn1)
* [Michel Echevres](https://github.com/echevresm)
* [Mistral Contrastin](https://github.com/madgen)
* [Jose Añasco](https://github.com/merongivian)
* [Daniel Canelhas](https://github.com/dcanelhas)
* [Katie Miller](https://github.com/codemiller)
* [Bruce Adams](https://github.com/bruceadams)
* [Christoph B. Wurzinger](https://github.com/chbw)
* [Serge Stinckwich](https://github.com/SergeStinckwich)
* [Nigel Michki](https://github.com/nigeil)
* [Joseph Haig](https://github.com/jrmhaig)
* [Graham Taylor](https://github.com/vinnievg)
* [John Lawrence Aspden](https://github.com/johnlawrenceaspden)
* [Cosmin Stroe](https://github.com/cstroe)
* [Ryan Bigg](https://github.com/radar)
* [Karl Hiner](https://github.com/khiner)
* [Morgan Owens](https://github.com/equiamos)
* [Ivan Zarea](https://github.com/minivan)
* [Alex McLean](https://github.com/yaxu)
* [Christian Perfect](https://github.com/christianp)
* [Michael Fulton](https://github.com/emu4hire)
* [Emlyn Corrin](https://github.com/emlyn)
* [James Smith](https://github.com/Nanomancer)
* [Hrafnkell Eiríksson](https://github.com/hrafnkelle)
* [Enrike Hurtado](https://github.com/enrike)
* [Tomasz Nurkiewicz](https://github.com/nurkiewicz)
* [Ruzsa Balázs](https://github.com/cellux)
* [Russell Jones](https://github.com/Russel-Jones)

==> Sonic-Pi-for-RPi-Wheezy-v2.9.0.tgz: sonic-pi-v2.9.0/CONTRIBUTORS.md <==
# Contributors

## Support and Advice

Thanks to the following people for their generous support (both
technical and otherwise) with time, advice, and wisdom:

* [Carrie Anne Philbin](https://twitter.com/missphilbin)
* [Robert Mullins](http://www.cl.cam.ac.uk/~rdm34/)
* [Alex Bradbury](https://twitter.com/asbradbury)
* [Alan Blackwell](http://www.cl.cam.ac.uk/~afb21/)
* [Rachel Drury](https://twitter.com/Rachel_Drury)
* [Juneau Projects](http://www.juneauprojects.co.uk)
* Stephan Lachowsky

## Organisations

The following organisations have kindly contributed to Sonic Pi:

* [The Raspberry Pi Foundation](http://www.raspberrypi.org)
* [The Broadcom Foundation](http://www.broadcomfoundation.org)
* [The University of Cambridge Computer Laboratory](http://www.cl.cam.ac.uk)
* [Nesta](http://www.nesta.org.uk)

## Developer Contributions

In addition to the Sonic Pi Core Team, I'd like to give my thanks to
the following developers who have donated their time and effort to help
grow and improve the Sonic Pi code base:

* [Hanno Zulla](https://github.com/hzulla)
* [Ethan Crawford](https://github.com/ethancrawford)
* [Łukasz Siwiński](https://github.com/hopbit)
* [Martin Keegan](https://github.com/mk270)
* [Nicolas Dermine](https://github.com/nicoder)
* [Ricardo Pozo](https://github.com/thraex41)
* [Kenichi Kanai](https://github.com/kn1kn1)
* [Robin Newman](https://github.com/rbnpi)
* [Wolfgang Werner](https://github.com/wwerner)
* [Clare Macrae](https://github.com/claremacrae)
* [Hannes Fritz](https://github.com/hztirf)
* [Petter Reinholdtsen](https://github.com/petterreinholdtsen)
* [G. Martin Butz](https://github.com/mbutz)
* [Marco Giordano](https://github.com/marco-giordano)
* [Keiko Machiya](https://github.com/keikomachiya)
* [Martin Zeilinger](https://github.com/st01c)
* [Steve Traylen](https://github.com/traylenator)
* [Chris Ford](https://github.com/ctford)
* [Mistral Contrastin](https://github.com/madgen)
* [Christoph B. Wurzinger](https://github.com/chbw)
* [Ben Nuttall](https://github.com/bennuttall)
* [Jose Añasco](https://github.com/merongivian)
* [Will Stephenson](https://github.com/wstephenson)
* [Frobby](https://github.com/frobby)
* [Michel Echevres](https://github.com/echevresm)
* [Katie Miller](https://github.com/codemiller)
* [Bruce Adams](https://github.com/bruceadams)
* [Daniel Canelhas](https://github.com/dcanelhas)
* [James Smith](https://github.com/Nanomancer)
* [Ryan Bigg](https://github.com/radar)
* [Joseph Haig](https://github.com/jrmhaig)
* [Graham Taylor](https://github.com/vinnievg)
* [Morgan Owens](https://github.com/equiamos)
* [Cosmin Stroe](https://github.com/cstroe)
* [Aspasia Beneti](https://github.com/aspasia)
* [Ivan Zarea](https://github.com/minivan)
* [Karl Hiner](https://github.com/khiner)
* [Serge Stinckwich](https://github.com/SergeStinckwich)
* [András Németh](https://github.com/nemethandras)
* [Nigel Michki](https://github.com/nigeil)
* [Christian Perfect](https://github.com/christianp)
* [Hrafnkell Eiríksson](https://github.com/hrafnkelle)
* [Ruzsa Balázs](https://github.com/cellux)
* [Enrike Hurtado](https://github.com/enrike)
* [Alex McLean](https://github.com/yaxu)
* [Russell Jones](https://github.com/Russell-Jones)
* [Michael Fulton](https://github.com/emu4hire)
* [Tomasz Nurkiewicz](https://github.com/nurkiewicz)
* [Emlyn Corrin](https://github.com/emlyn)
* [John Lawrence Aspden](https://github.com/johnlawrenceaspden)
